None

Struct None 

pub struct None { /* private fields */ }

Implementations

Source

impl None

pub const fn new(ty: u8, nr: u8) -> Self

pub const fn cmd(&self) -> u32

pub unsafe fn call(&self, fd: &impl AsRawFd) -> Result<i32>

Calls the ioctl on a file descriptor.

Safety

This library does know know about the different ioctls. It is up to the caller to ensure that the ioctl it is making is safe.